==> admin-util-5.1.0-sources.jar: com/sun/enterprise/admin/commands/SslConfigHandler.java <==
/*
 * Copyright (c) 2011, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.enterprise.admin.commands;

import org.glassfish.api.ActionReport;
import org.jvnet.hk2.annotations.Contract;

/**
 * Contract for handling the SSL related configuration.
 * @author Jerome Dochez
 */
@Contract
public interface SslConfigHandler {

    /**
     * creates the SSL configuration for a particular create-ssl command
     * invocation.
     *
     * @param command the create-ssl command instance
     * @param report where to place the result of the configuration
     * population.
     */
    void create(CreateSsl command, ActionReport report);

    /**
     * Deletes the SSL configuration for a delete-ssl command invocation
     *
     * @param command the delete-ssl command instance where command parameters can be obtained
     * @param report where to place the result
     */
    void delete(DeleteSsl command, ActionReport report);
}

==> admin-util-6.1.0-sources.jar: com/sun/enterprise/admin/commands/SslConfigHandler.java <==
/*
 * Copyright (c) 2011, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.enterprise.admin.commands;

import org.glassfish.api.ActionReport;
import org.jvnet.hk2.annotations.Contract;

/**
 * Contract for handling the SSL related configuration.
 * 
 * @author Jerome Dochez
 */
@Contract
public interface SslConfigHandler {

    /**
     * creates the SSL configuration for a particular create-ssl command invocation.
     *
     * @param command the create-ssl command instance
     * @param report where to place the result of the configuration population.
     */
    void create(CreateSsl command, ActionReport report);

    /**
     * Deletes the SSL configuration for a delete-ssl command invocation
     *
     * @param command the delete-ssl command instance where command parameters can be obtained
     * @param report where to place the result
     */
    void delete(DeleteSsl command, ActionReport report);
}
